UseCaseDiagnosticValueKind enum
Kinds of application values that UseCase Forge DevTools can request.
Values
- state → const UseCaseDiagnosticValueKind
-
A current or published State value.
- command → const UseCaseDiagnosticValueKind
-
A submitted command object.
- executionKey → const UseCaseDiagnosticValueKind
-
A command execution key.
- reason → const UseCaseDiagnosticValueKind
-
A snapshot or terminal reason.
- error → const UseCaseDiagnosticValueKind
-
An error caught by the runtime.
- stackTrace → const UseCaseDiagnosticValueKind
-
A stack trace associated with an error.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UseCaseDiagnosticValueKind> - A constant List of the values in this enum, in order of their declaration.